==> ekiga-3.1.0.tar.gz: ekiga-3.1.0/lib/engine/components/avahi-publisher/avahi-publisher-main.cpp <==

/* Ekiga -- A VoIP and Video-Conferencing application
 * Copyright (C) 2000-2009 Damien Sandras <dsandras@seconix.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 *
 * Ekiga is licensed under the GPL license and as a special exception,
 * you have permission to link or otherwise combine this program with the
 * programs OPAL, OpenH323 and PWLIB, and distribute the combination,
 * without applying the requirements of the GNU GPL to the OPAL, OpenH323
 * and PWLIB programs, as long as you do follow the requirements of the
 * GNU GPL for all the rest of the software thus combined.
 */


/*
 *                         avahi-publisher-main.cpp  -  description
 *                         ------------------------------------------
 *   begin                : written in 2008 by Damien Sandras
 *   copyright            : (c) 2008 Damien Sandras
 *   description          : code to hook the avahi publisher into the main program
 *
 */

#include "avahi-publisher-main.h"
#include "avahi-publisher.h"

#include <iostream>

bool
avahi_publisher_init (Ekiga::ServiceCore &core,
                      int* /*argc*/,
                      char* */*argv*/[])
{
  bool result = false;
  gmref_ptr<Ekiga::PresenceCore> presence_core
    = core.get ("presence-core");
  gmref_ptr<Ekiga::CallCore> call_core = core.get ("call-core");
  gmref_ptr<Ekiga::PersonalDetails> details = core.get ("personal-details");

  if (presence_core && call_core && details) {

    gmref_ptr<Avahi::PresencePublisher> publisher (new Avahi::PresencePublisher (core, *details, *call_core));
    presence_core->add_presence_publisher (publisher);
    core.add (publisher);
    result = true;
  }

  return result;
}

==> ekiga_3.2.7.orig.tar.gz: ekiga-3.2.7/lib/engine/components/avahi-publisher/avahi-publisher-main.cpp <==

/* Ekiga -- A VoIP and Video-Conferencing application
 * Copyright (C) 2000-2009 Damien Sandras <dsandras@seconix.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 *
 * Ekiga is licensed under the GPL license and as a special exception,
 * you have permission to link or otherwise combine this program with the
 * programs OPAL, OpenH323 and PWLIB, and distribute the combination,
 * without applying the requirements of the GNU GPL to the OPAL, OpenH323
 * and PWLIB programs, as long as you do follow the requirements of the
 * GNU GPL for all the rest of the software thus combined.
 */


/*
 *                         avahi-publisher-main.cpp  -  description
 *                         ------------------------------------------
 *   begin                : written in 2008 by Damien Sandras
 *   copyright            : (c) 2008 Damien Sandras
 *   description          : code to hook the avahi publisher into the main program
 *
 */

#include "avahi-publisher-main.h"
#include "avahi-publisher.h"

struct AVAHIPUBSpark: public Ekiga::Spark
{
  AVAHIPUBSpark (): result(false)
  {}

  bool try_initialize_more (Ekiga::ServiceCore& core,
			    int* /*argc*/,
			    char** /*argv*/[])
  {
    gmref_ptr<Ekiga::Service> service = core.get ("avahi-presence-publisher");
    gmref_ptr<Ekiga::PresenceCore> presence_core = core.get ("presence-core");
    gmref_ptr<Ekiga::CallCore> call_core = core.get ("call-core");
    gmref_ptr<Ekiga::PersonalDetails> details = core.get ("personal-details");

    if (presence_core && call_core && details && !service) {

      gmref_ptr<Avahi::PresencePublisher> publisher (new Avahi::PresencePublisher (core, *details, *call_core));
      presence_core->add_presence_publisher (publisher);
      core.add (publisher);
      result = true;
    }

    return result;
  }

  Ekiga::Spark::state get_state () const
  { return result?FULL:BLANK; }

  const std::string get_name () const
  { return "AVAHIPUB"; }

  bool result;
};

void
avahi_publisher_init (Ekiga::KickStart& kickstart)
{
  gmref_ptr<Ekiga::Spark> spark(new AVAHIPUBSpark);
  kickstart.add_spark (spark);
}
